#
# spec file for package spice
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Common info
Name:           spice
Version:        0.12.7
Release:        3.1
Summary:        SPICE client and server library
License:        LGPL-2.1+
Group:          Productivity/Networking/Other
Url:            http://www.spice-space.org/
Source:         http://spice-space.org/download/releases/%{name}-%{version}.tar.bz2
# Patches for CVE-2016-0749 and CVE-2016-2150
Patch0:         CVE-2016-0749-add-a-ref-to-item-before-adding-to-pipe.patch
Patch1:         CVE-2016-0749-allocate-msg-with-the-expected-size.patch
Patch2:         CVE-2016-2150-create-a-function-to-validate-surface-parameters.patch
Patch3:         CVE-2016-2150-improve-primary-surface-parameter-checks.patch
Patch4:         CVE-2016-9577-buffer-overflow-in-main_channel_alloc_msg_rcv_buf.patch
Patch5:         CVE-2016-9578-remote-dos-via-crafted-message.patch

# Build-time parameters
BuildRequires:  alsa-devel
BuildRequires:  celt051-devel
BuildRequires:  cyrus-sasl-devel
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libpixman-1-0-devel >= 0.17.7
BuildRequires:  pkg-config
BuildRequires:  python-pyparsing
BuildRequires:  python-six
BuildRequires:  spice-protocol-devel >= 0.12.10
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(glib-2.0) >= 2.22
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xrender)
# Install-time parameters
Requires:       celt051
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  %ix86 x86_64

%description
The SPICE package provides the SPICE server library and client.
These components are used to provide access to a remote machine's
display and devices.

%package -n spice-client
Summary:        SPICE client
Group:          Productivity/Networking/Other

%description -n spice-client
The SPICE client provides access to a remote machine's display and devices.

%package -n libspice-server1
Summary:        Library for SPICE-server
Group:          Productivity/Networking/Other

%description -n libspice-server1
Library for SPICE-server
The SPICE server is used to expose a remote machine's display
and devices.

%package -n libspice-server-devel
Summary:        Development files for building SPICE-server
Group:          Development/Languages/C and C++
Requires:       libspice-server1 = %{version}

%description -n libspice-server-devel
Development files for building SPICE-server.
The SPICE server is used to expose a remote machine's display
and devices.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
%configure \
        --disable-static \
        --enable-client \
        --disable-smartcard
 LDFLAGS="-Wl,--as-needed -Wl,--strip-all"
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libspice-server1 -p /sbin/ldconfig

%postun -n libspice-server1 -p /sbin/ldconfig

%files -n spice-client
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README

%files -n libspice-server1
%defattr(-,root,root)
%{_libdir}/libspice-server.so.*

%files -n libspice-server-devel
%defattr(-,root,root)
%{_libdir}/pkgconfig/spice-server.pc
%{_includedir}/spice-server/
%{_libdir}/libspice-server.so

%changelog
* Thu Feb  2 2017 psimons@suse.com
- Added patches to fix two security vulnerabilities.
  * CVE-2016-9577-buffer-overflow-in-main_channel_alloc_msg_rcv_buf.patch
    [CVE-2016-9577, bsc#1023078]
  * CVE-2016-9578-remote-dos-via-crafted-message.patch
    [CVE-2016-9578, bsc#1023079]
* Thu Jun  2 2016 cbosdonnat@suse.com
- Fixes for bsc#982385 / CVE-2016-0749 and bsc#982386 / CVE-2016-2150
  CVE-2016-0749-smartcard-add-a-ref-to-item-before-adding-to-pipe.patch
  CVE-2016-0749-smartcard-allocate-msg-with-the-expected-size.patch
  CVE-2016-2150-create-a-function-to-validate-surface-parameters.patch
  CVE-2016-2150-improve-primary-surface-parameter-checks.patch
* Fri Apr 15 2016 cbosdonnat@suse.com
- Update to version 0.12.7 (fate#320079)
  + spice-server will now send TCP keepalive probes on the TCP connections it
    uses. This can prevent unwanted idle disconnections if proxies are used
    between the client and the host.
  + Fix important memory usage when the webdav channel is used
  + Do not disconnect when the client requests an unsupported compression type
  + Fix a few race conditions
  + Fix display glitch when using XSpice
  + Improve help string for 'replay -s'
  + Fix crashes in corner cases (buggy spice-html5 + win10, vnc + SPICE port
    configured, USB webcam redirection over a slow link)
  + Fix various compilation warning when building on 32 bit machines
  + Some fixes for big-endian machines, more work is likely to be needed
  + Do not build static libraries by default, this can be reenabled with --enable-static
  + Fix small leak in MJPEG code
* Tue Oct  6 2015 cbosdonnat@suse.com
- Update to version 0.12.6
  + Removed spicec client code, it has been superseded by remote-viewer
    and other spice-gtk based clients
  + Unix socket support
  + Let clients specify their preferred image compression format
  + Allow to record and replay a spice-server session
  + Fixes for CVE-2015-3247 CVE-2015-5260 and CVE-2015-5261
    bsc#944787, bsc#948976
  + spice-protocol submodule has been removed, spice-protocol must
    now be installed when building spice-server
  + Remove write polling in chardevs to reduce wakeups
- Remove upstream merged patches:
  + spice-Don-t-use-48kHz-for-playback-recording-rates.patch
  + password-length-check.patch
  + cve-2015-3247.patch
- Replace xorg-x11-devel buildrequire by selected pkgconfig(xlibs..)
* Mon Sep  7 2015 cbosdonnat@suse.com
- bsc#944460: fix CVE-2015-3247.
  cve-2015-3247.patch
* Fri Jun  5 2015 cbosdonnat@suse.com
- Don't allow setting password longer than what the spice protocol
  allows. password-length-check.patch. boo#931044
- Update to version 0.12.5:
  + Added Opus support. Celt support will be obsoleted in a future
    release.
  + Addition of webdav channel.
  + Force use of TLS 1.0 or newer for TLS connections.
  + Reference manual.
  + Some optimizations improving CPU use.
  + Various bug fixes for race conditions, memory corruption, which
    could be triggered on client disconnections, migration, and
    cause spice-server to misbehave.
  + Portability fixes.
  + Code cleanups.
- Add pkconfig(opus) BuildRequires: Needed to build new opus
  support.
- Add spice-Don-t-use-48kHz-for-playback-recording-rates.patch:
  Fix advertised sound playback/recording rates in public headers
  (rh#1129961).
- Run spec-clean on spec file, remove conditionals for obsolete
  versions of openSUSE, enable parallel build and drop obsolete
  clean section.
- Drop now useless patches:
  + 8af61900-cve-2013-4282-fix.patch
  + spice-glibc217.patch
- Replace xorg-x11-devel buildrequire by selected pkgconfig(xlibs..)
* Wed Apr  1 2015 cbosdonnat@suse.com
- bsc#848279: fix CVE-2013-4282.
  8af61900-cve-2013-4282-fix.patch
* Tue Sep  2 2014 cbosdonnat@suse.com
- bnc#894069: disable smartcard support
* Mon Jul 29 2013 aevseev@gmail.com
- Update to version 0.12.4:
  + log actual address spice-server binds to
  + main_channel: fix double release of migration target data (rhbz#859027)
  + red_channel: replace an assert upon threads mismatch with a warning (rhbz#823472)
  + support for filtering out agent file-xfer msgs (rhbz#961848)
  ++ new library export spice_server_set_agent_file_xfer
  + mjpeg encoder statistics (mjpeg_encoder_get_stats)
  + improve stream stats readability and ease of parsing
  + fix for stuck display_channel over WAN (jpeg_enabled=true) (rhbz#977998)
  + Use RING_FOREACH_SAFE and other SAFE macros (rhbz#887775)
  + Some server/tests fixes.
- New features from 0.12.3:
  + monitor client bandwidth and latency.
  + dynamically adjust video stream quality based on client bandwidth & latency.
  ++ new SPICE_MSGC_DISPLAY_STREAM_REPORT
  ++ can also set SPICE_BIT_RATE environment variable to override.
  + support arbitrary latency of audio stream wrt video stream:
  ++ new SPICE_MSG_PLAYBACK_LATENCY
  + notify agent on client disconnection
  ++ new VD_AGENT_CLIENT_DISCONNECTED message
  + better support for switching from qxl to vga mode
  ++ new library export spice_qxl_driver_unload
  + multiple monitor support in single channel fixes.
  + stop streams before migration.
  + don't send empty volume messages.
  + Bugs fixed: rhbz#891326, rhbz#958276, rhbz#956345
  + fixes to inputs, chardev, build fixes.
* Wed May 15 2013 dimstar@opensuse.org
- Update to version 0.12.2:
  + Skipped 0.12.1, it existed in git but was never released.
  + spice-server now requires glib2 (like qemu does).
  + More robust ssl error and certificate handling.
  + Added support for websockets.
  + Tons of seamless migration bugfixes.
  + Also some none seamless migration bugfixes.
- Clean spec file using spec-cleaner.
- Rebase spice-glibc217.patch.
- Add pkgconfig(glib-2.0) BuildRequires: new dependency.
- Pass --enable-client and --enable-smartcard to configure in
  order to ensure the client and smartcard support are built (SC
  only on openSUSE >= 12.2).
* Thu Nov 22 2012 afaerber@suse.de
- Update to version 0.12.0
  * support setting client monitor configuration via device
  QXLInterface::client_monitors_config
  * support notifying guest of client capabilities
  QXLInterface::set_client_capabilities
  * new capability for A8 Surface support
  * Enable build on armv6+
  * Option to quit server after first client disconnects
  spice_server_set_exit_on_disconnect
  * Support seamless migration: no loss of in transit messages. Still not
  supported for agent, smartcard and usb.
  * Support a new rendering message, Composite, for much improved linux guest
  performance.
  * Support arbitrary resolution & multiple monitors on a single display channel.
  * Improved keyboard handling under network latency with new
  SPICE_MSGC_INPUTS_KEY_SCANCODE message.
  * New libspice-server.so symbols:
  spice_server_set_seamless_migration
  spice_server_vm_stop
  spice_server_vm_start
  spice_qxl_monitors_config_async
  * New capabilities:
  SPICE_DISPLAY_CAP_COMPOSITE
  SPICE_DISPLAY_CAP_MONITORS_CONFIG
  SPICE_INPUTS_CAP_KEY_SCANCODE
  SPICE_MAIN_CAP_AGENT_CONNECTED_TOKENS
  SPICE_MAIN_CAP_SEAMLESS_MIGRATE
  * Misc:
  * char_device.c: Introducing shared flow control code for char devices
  * Enable build without client, cegui and slirp.
  * New spice protocol messages: (changes in spice-protocol, here for reference)
  * SPICE_MSG_MAIN_NAME, SPICE_MSG_MAIN_UUID
  * SPICE_MSG_DISPLAY_STREAM_DATA_SIZED
  * New corresponding caps: (changes in spice-protocol, here for reference)
  * SPICE_MAIN_CAP_NAME_AND_UUID
  * SPICE_DISPLAY_CAP_SIZED_STREAM.
  * Send name & uuid to capable clients
  * add support for frames of different sizes RHBZ #813826
  * server:
  * support a pre-opened file descriptor
  * Solaris support. Now using poll instead of epoll.
  * Support IPV6 addresses in channel events RHBZ #788444
  * other fixed RHBZ#: 787669, 787678, 819484
  * spicec
  * alsa: use "default" instead of "hw:0,0"
  * volume keys support RHBZ #552539
  * other fixed RHBZ#: 78655, 804561, 641828
  * solaris, mingw & windows, 32 bit fixes.
  * enable server only build.
  * GNULIB manywarnings.m4 & warnings.m4 module added.
  * Many more bug fixes & code cleanups.
  * spice-protocol no longer external.
  * new server functions:
  + spice_server_set_name
  + spice_server_set_uuid
  + spice_server_set_listen_socket_fd
  + spice_server_is_server_mouse
- Drop spice-gcc47.patch
- Update spice-glibc217.patch (file moved)
* Sat Nov 17 2012 aj@suse.de
- Fix build with glibc 2.17 (add patch spice-glibc217.patch).
* Mon Apr  2 2012 dimstar@opensuse.org
- Add spice-gcc47.patch: Fix build with gcc 4.7. Most of this used
  to be in spice-signed-comparison.patch which got dropped with
  latest update.
* Sun Apr  1 2012 zaitor@opensuse.org
- Update to version 0.10.1:
  + Mini header support.
  + Add server API for injecting a client connection socket.
  + Add Xinerama support to spicec.
  + Many bugfixes / code cleanups.
  + Requires spice-protocol >= 0.10.1
- Drop spice-signed-comparison.patch and
  0001-server-red_parse_qxl.h-License-should-be-LGPLv2-rath.patch
  Fixed upstream.
* Mon Mar 19 2012 dimstar@opensuse.org
- Extend spice-signed-comparison.patch: incl. git commit 965a1a.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Thu Jan  5 2012 dvaleev@suse.com
- Only x86 and x86-64 are supported
* Tue Dec 13 2011 brogers@suse.com
- Initial package, prepared for inclusion in Factory.
